==> onos-yang-runtime-2.2.0-b1-sources.jar: org/onosproject/yang/gen/v1/ietfl3vpnsvc/rev20160730/ietfl3vpnsvc/RoutingProtocolType.java <==
/*
 * Copyright 2017-present Open Networking Laboratory
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.ietfl3vpnsvc.rev20160730.ietfl3vpnsvc;
/**
 * Represents the implementation of routingProtocolType.
 */
public abstract class RoutingProtocolType {

    /**
     * Returns the attribute routing-protocol-type.
     *
     * @return routing-protocol-type value of routing-protocol-type
     */
    public static String routingProtocolTypeToString() {
        return "routing-protocol-type";
    }

    /**
     * Returns the object of routingProtocolType fromString input String routingProtocolType.
     *
     * @param valInString value of input String
     * @return routingProtocolType
     */
    public static Class fromString(String valInString) {
        if (valInString.equals("routing-protocol-type")) {
            return RoutingProtocolType.class;
        }
        throw new IllegalArgumentException("not a valid input element");
    }
}

==> onos-yang-runtime-2.3.1-sources.jar: org/onosproject/yang/gen/v1/ietfl3vpnsvc/rev20160730/ietfl3vpnsvc/RoutingProtocolType.java <==
/*
 * Copyright 2017-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.ietfl3vpnsvc.rev20160730.ietfl3vpnsvc;

/**
 * Represents the implementation of routingProtocolType.
 */
public abstract class RoutingProtocolType {

    /**
     * Returns the attribute routing-protocol-type.
     *
     * @return routing-protocol-type value of routing-protocol-type
     */
    public static String routingProtocolTypeToString() {
        return "routing-protocol-type";
    }

    /**
     * Returns the object of routingProtocolType fromString input String routingProtocolType.
     *
     * @param valInString value of input String
     * @return routingProtocolType
     */
    public static Class fromString(String valInString) {
        if (valInString.equals("routing-protocol-type")) {
            return RoutingProtocolType.class;
        } else if (valInString.equals("ospf")) {
            return Ospf.class;
        } else if (valInString.equals("bgp")) {
            return Bgp.class;
        } else if (valInString.equals("static")) {
            return YangAutoPrefixStatic.class;
        } else if (valInString.equals("rip")) {
            return Rip.class;
        } else if (valInString.equals("rip-ng")) {
            return RipNg.class;
        } else if (valInString.equals("vrrp")) {
            return Vrrp.class;
        } else if (valInString.equals("direct")) {
            return Direct.class;
        }
        throw new IllegalArgumentException("not a valid input element");
    }
}
